@@ -29,6 +29,7 @@
 
 FaviconObject::FaviconObject(QObject *parent)
   : QObject(parent)
+  , networkManager_(NULL)
 {
   setObjectName("faviconObject_");
 
@@ -43,22 +44,25 @@ FaviconObject::FaviconObject(QObject *parent)
 
   connect(this, SIGNAL(signalGet(QUrl,QString,int)),
           SLOT(slotGet(QUrl,QString,int)));
-
-  networkManager_ = new NetworkManager(true, this);
-  connect(networkManager_, SIGNAL(finished(QNetworkReply*)),
-          this, SLOT(finished(QNetworkReply*)));
 }
 
 void FaviconObject::disconnectObjects()
 {
   disconnect(this);
-  networkManager_->disconnect(networkManager_);
+  if (networkManager_)
+    networkManager_->disconnect(networkManager_);
 }
 
 /** @brief Put requested URL in request queue
  *----------------------------------------------------------------------------*/
 void FaviconObject::requestUrl(QString urlString, QString feedUrl)
 {
+  if (!networkManager_) {
+    networkManager_ = new NetworkManager(true, this);
+    connect(networkManager_, SIGNAL(finished(QNetworkReply*)),
+            this, SLOT(finished(QNetworkReply*)));
+  }
+
   if (!timeout_->isActive())
     timeout_->start();
 
@@ -73,7 +77,7 @@ void FaviconObject::requestUrl(QString urlString, QString feedUrl)
  *----------------------------------------------------------------------------*/
 void FaviconObject::getQueuedUrl()
 {
-  if (currentFeeds_.size() >= REPLY_MAX_COUNT) {
+  if (currentFeeds_.count() >= REPLY_MAX_COUNT) {
     getUrlTimer_->start();
     return;
   }
@@ -106,14 +110,17 @@ void FaviconObject::getQueuedUrl()
 
 /** @brief Prepare and send network request to receive all data
  *----------------------------------------------------------------------------*/
-void FaviconObject::slotGet(const QUrl &getUrl, const QString &feedUrl, const int &cnt)
+void FaviconObject::slotGet(const QUrl &getUrl, const QString &feedUrl, const int &count)
 {
+  if (count)
+    Common::sleep(30);
+
   QNetworkRequest request(getUrl);
   request.setRawHeader("User-Agent", globals.userAgent().toUtf8());
 
   currentUrls_.append(getUrl);
   currentFeeds_.append(feedUrl);
-  currentCntRequests_.append(cnt);
+  currentCntRequests_.append(count);
   currentTime_.append(REQUEST_TIMEOUT);
 
   QNetworkReply *reply = networkManager_->get(request);
