@@ -18,6 +18,9 @@
 #include "globals.h"
 #include "mainapplication.h"
 #include "logfile.h"
+#if defined(Q_OS_WIN)
+#include <windows.h>
+#endif
 
 int main(int argc, char **argv)
 {
@@ -29,6 +32,11 @@ int main(int argc, char **argv)
 #endif
   }
 
+#ifdef Q_OS_WIN
+#if _WIN32_WINNT >= 0x0600
+  SetProcessDPIAware();
+#endif
+#endif
 #if QT_VERSION >= 0x050600
   QApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
 #elif QT_VERSION >= 0x050400
