@@ -32,7 +32,6 @@
 
 ParseObject::ParseObject(QObject *parent)
   : QObject(parent)
-  , currentFeedId_(0)
 {
   setObjectName("parseObject_");
 
@@ -77,20 +76,23 @@ void ParseObject::parseXml(QByteArray data, int feedId,
  *----------------------------------------------------------------------------*/
 void ParseObject::getQueuedXml()
 {
-  if (currentFeedId_) return;
+  if (!mutex_.tryLock())
+    return;
 
   if (idsQueue_.count()) {
-    currentFeedId_ = idsQueue_.dequeue();
+    int feedId = idsQueue_.dequeue();
     QByteArray currentXml_ = xmlsQueue_.dequeue();
     QDateTime currentDtReady_ = dtReadyQueue_.dequeue();
     QString currentCodecName_ = codecNameQueue_.dequeue();
-    qDebug() << "xmlsQueue_ >>" << currentFeedId_ << "count=" << xmlsQueue_.count();
+    qDebug() << "xmlsQueue_ >>" << feedId << "count=" << xmlsQueue_.count();
 
-    emit signalReadyParse(currentXml_, currentFeedId_, currentDtReady_, currentCodecName_);
-
-    currentFeedId_ = 0;
-    parseTimer_->start();
+    emit signalReadyParse(currentXml_, feedId, currentDtReady_, currentCodecName_);
   }
+
+  mutex_.unlock();
+
+  if (idsQueue_.count())
+    parseTimer_->start();
 }
 
 /** @brief Parse xml-data
@@ -140,6 +142,7 @@ void ParseObject::slotParse(const QByteArray &xmlData, const int &feedId,
 
   // actually parsing
   feedChanged_ = false;
+  lastBuildDate_ = dtReply;
 
   bool codecOk = false;
   QString convertData(xmlData);
@@ -245,7 +248,7 @@ void ParseObject::slotParse(const QByteArray &xmlData, const int &feedId,
   // Set feed update time and receive data from server time
   QString updated = QLocale::c().toString(QDateTime::currentDateTimeUtc(),
                                           "yyyy-MM-ddTHH:mm:ss");
-  QString lastBuildDate = dtReply.toString(Qt::ISODate);
+  QString lastBuildDate = lastBuildDate_.toString(Qt::ISODate);
   q.prepare("UPDATE feeds SET updated=?, lastBuildDate=?, status=0 WHERE id=?");
   q.addBindValue(updated);
   q.addBindValue(lastBuildDate);
@@ -310,6 +313,10 @@ void ParseObject::parseAtom(const QString &feedUrl, const QDomDocument &doc)
   if (QUrl(feedItem.link).host().isEmpty())
     feedItem.link = feedItem.linkBase + feedItem.link;
   feedItem.link = toPlainText(feedItem.link);
+  QUrl url = QUrl(feedItem.link);
+  if (url.scheme().isEmpty())
+    url.setScheme(QUrl(feedUrl).scheme());
+  feedItem.link = url.toString();
 
   QSqlQuery q(db_);
   q.setForwardOnly(true);
@@ -360,20 +367,30 @@ void ParseObject::parseAtom(const QString &feedUrl, const QDomDocument &doc)
     } else {
       newsItem.content = nodeContent.toElement().text();
     }
-    if (newsItem.content.isEmpty()) {
-      nodeContent = newsList.item(i).namedItem("media:group");
-      if (!nodeContent.isNull()) {
-        QString description = nodeContent.namedItem("media:description").toElement().text();
-        QString media = nodeContent.namedItem("media:thumbnail").toElement().attribute("url");
-        newsItem.content += "<p class=\"description\">" + description + "</p>";
-        newsItem.content += "<img src=\"" + media + "\" alt=\"image\"/>";
-      }
+    QString imgUrl = newsList.item(i).namedItem("media:thumbnail").toElement().attribute("url");
+    QString community = getCommunity(newsList.item(i).namedItem("media:community"));
+    nodeContent = newsList.item(i).namedItem("media:group");
+    if (!nodeContent.isNull()) {
+      QString description = nodeContent.namedItem("media:description").toElement().text();
+      if (description.length() > newsItem.content.length())
+        newsItem.content = description;
+      newsItem.content = fromPlainText(newsItem.content);
+      if (imgUrl.isEmpty())
+        imgUrl = nodeContent.namedItem("media:thumbnail").toElement().attribute("url");
+      if (community.isEmpty())
+        community = getCommunity(nodeContent.namedItem("media:community"));
     }
     if (!(newsItem.content.isEmpty() ||
           (newsItem.description.length() > newsItem.content.length()))) {
       newsItem.description = newsItem.content;
     }
     newsItem.content.clear();
+    if (!imgUrl.isEmpty()) {
+      newsItem.description = "<p class=\"description\">" + newsItem.description + "</p>";
+      newsItem.description += "<img src=\"" + imgUrl + "\" alt=\"image\"/>";
+    }
+    if (!community.isEmpty())
+      newsItem.description += community;
 
     QDomNodeList categoryElem = newsList.item(i).toElement().elementsByTagName("category");
     for (int j = 0; j < categoryElem.size(); j++) {
@@ -420,6 +437,10 @@ void ParseObject::parseAtom(const QString &feedUrl, const QDomDocument &doc)
       newsItem.link = newsItem.linkAlternate;
       newsItem.linkAlternate.clear();
     }
+    url = QUrl(newsItem.link);
+    if (url.scheme().isEmpty())
+      url.setScheme(QUrl(feedUrl).scheme());
+    newsItem.link = url.toString();
 
     addAtomNewsIntoBase(&newsItem);
   }
@@ -541,6 +562,9 @@ void ParseObject::addAtomNewsIntoBase(NewsItemStruct *newsItem)
     qDebug() << "       " << newsItem->eUrl;
     qDebug() << "       " << newsItem->eType;
     qDebug() << "       " << newsItem->eLength;
+
+    if (lastBuildDate_ < QDateTime::fromString(newsItem->updated, Qt::ISODate))
+      lastBuildDate_ = QDateTime::fromString(newsItem->updated, Qt::ISODate);
     feedChanged_ = true;
   }
 }
@@ -638,12 +662,30 @@ void ParseObject::parseRss(const QString &feedUrl, const QDomDocument &doc)
       QTextStream in(&newsItem.content);
       nodeContent.save(in, 0);
     }
-
-    if (newsItem.content.isEmpty() || (newsItem.description.length() > newsItem.content.length())) {
-      newsItem.content.clear();
-    } else {
+    QString imgUrl = newsList.item(i).namedItem("media:thumbnail").toElement().attribute("url");
+    QString community = getCommunity(newsList.item(i).namedItem("media:community"));
+    nodeContent = newsList.item(i).namedItem("media:group");
+    if (!nodeContent.isNull()) {
+      QString description = nodeContent.namedItem("media:description").toElement().text();
+      if (description.length() > newsItem.content.length())
+        newsItem.content = description;
+      newsItem.content = fromPlainText(newsItem.content);
+      if (imgUrl.isEmpty())
+        imgUrl = nodeContent.namedItem("media:thumbnail").toElement().attribute("url");
+      if (community.isEmpty())
+        community = getCommunity(nodeContent.namedItem("media:community"));
+    }
+    if (!(newsItem.content.isEmpty() ||
+          (newsItem.description.length() > newsItem.content.length()))) {
       newsItem.description = newsItem.content;
     }
+    newsItem.content.clear();
+    if (!imgUrl.isEmpty()) {
+      newsItem.description = "<p class=\"description\">" + newsItem.description + "</p>";
+      newsItem.description += "<img src=\"" + imgUrl + "\" alt=\"image\"/>";
+    }
+    if (!community.isEmpty())
+      newsItem.description += community;
 
     QDomNodeList categoryElem = newsList.item(i).toElement().elementsByTagName("category");
     for (int j = 0; j < categoryElem.size(); j++) {
@@ -825,6 +867,9 @@ void ParseObject::addRssNewsIntoBase(NewsItemStruct *newsItem)
     qDebug() << "       " << newsItem->eUrl;
     qDebug() << "       " << newsItem->eType;
     qDebug() << "       " << newsItem->eLength;
+
+    if (lastBuildDate_ < QDateTime::fromString(newsItem->updated, Qt::ISODate))
+      lastBuildDate_ = QDateTime::fromString(newsItem->updated, Qt::ISODate);
     feedChanged_ = true;
   }
 }
@@ -834,6 +879,33 @@ QString ParseObject::toPlainText(const QString &text)
   return QTextDocumentFragment::fromHtml(text).toPlainText().simplified();
 }
 
+QString ParseObject::fromPlainText(QString text)
+{
+  text = text.replace("\r\n", "<br>");
+  text = text.replace("\n", "<br>");
+  return text;
+}
+
+QString ParseObject::getCommunity(const QDomNode &nodeContent)
+{
+  QString community;
+  if (!nodeContent.isNull()) {
+    QString count = nodeContent.namedItem("media:starRating").toElement().attribute("count");
+    QString average = nodeContent.namedItem("media:starRating").toElement().attribute("average");
+    QString min = nodeContent.namedItem("media:starRating").toElement().attribute("min");
+    QString max = nodeContent.namedItem("media:starRating").toElement().attribute("max");
+    QString views = nodeContent.namedItem("media:statistics").toElement().attribute("views");
+    if (!count.isEmpty())
+      community = QString("Count: %1, average: %2, min: %3, max: %4<br>").
+          arg(count).arg(average).arg(min).arg(max);
+    if (!views.isEmpty())
+      community += QString("Views: %1").arg(views);
+    if (!community.isEmpty())
+      community = "<p><i>" + community + "</i></p>";
+  }
+  return community;
+}
+
 /** @brief Date/time string parsing
  *----------------------------------------------------------------------------*/
 QString ParseObject::parseDate(const QString &dateString, const QString &urlString)
