@@ -1,6 +1,6 @@
 /* ============================================================
 * QuiteRSS is a open-source cross-platform RSS/Atom news feeds reader
-* Copyright (C) 2011-2014 QuiteRSS Team <quiterssteam@gmail.com>
+* Copyright (C) 2011-2020 QuiteRSS Team <quiterssteam@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -13,7 +13,7 @@
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
+* along with this program.  If not, see <https://www.gnu.org/licenses/>.
 * ============================================================ */
 #include "updatefeeds.h"
 
@@ -22,6 +22,7 @@
 #include "settings.h"
 
 #include <QDebug>
+#include <qzregexp.h>
 
 #define UPDATE_INTERVAL 3000
 #define UPDATE_INTERVAL_MIN 500
@@ -74,6 +75,8 @@ UpdateFeeds::UpdateFeeds(QObject *parent, bool addFeed)
             updateObject_, SLOT(getUrlDone(int,int,QString,QString,QByteArray,QDateTime,QString)));
     connect(requestFeed_, SIGNAL(setStatusFeed(int,QString)),
             parent, SLOT(setStatusFeed(int,QString)));
+    connect(parent, SIGNAL(signalStopUpdate()),
+            requestFeed_, SLOT(stopRequest()));
 
     connect(parent, SIGNAL(signalGetFeedTimer(int)),
             updateObject_, SLOT(slotGetFeedTimer(int)));
@@ -121,8 +124,8 @@ UpdateFeeds::UpdateFeeds(QObject *parent, bool addFeed)
             updateObject_, SLOT(slotNextUpdateFeed(bool)));
     connect(updateObject_, SIGNAL(signalUpdateModel(bool)),
             parent, SLOT(feedsModelReload(bool)));
-    connect(updateObject_, SIGNAL(signalUpdateNews()),
-            parent, SLOT(slotUpdateNews()));
+    connect(updateObject_, SIGNAL(signalUpdateNews(int)),
+            parent, SLOT(slotUpdateNews(int)));
     connect(updateObject_, SIGNAL(signalCountsStatusBar(int,int)),
             parent, SLOT(slotCountsStatusBar(int,int)));
 
@@ -130,7 +133,8 @@ UpdateFeeds::UpdateFeeds(QObject *parent, bool addFeed)
             updateObject_, SLOT(slotRecountCategoryCounts()));
     qRegisterMetaType<QList<int> >("QList<int>");
     connect(updateObject_, SIGNAL(signalRecountCategoryCounts(QList<int>,QList<int>,QList<int>,QStringList)),
-            parent, SLOT(slotRecountCategoryCounts(QList<int>,QList<int>,QList<int>,QStringList)));
+            parent, SLOT(slotRecountCategoryCounts(QList<int>,QList<int>,QList<int>,QStringList)),
+            Qt::QueuedConnection);
     connect(parent, SIGNAL(signalRecountFeedCounts(int,bool)),
             updateObject_, SLOT(slotRecountFeedCounts(int,bool)));
     connect(updateObject_, SIGNAL(feedCountsUpdate(FeedCountStruct)),
@@ -138,7 +142,8 @@ UpdateFeeds::UpdateFeeds(QObject *parent, bool addFeed)
     connect(updateObject_, SIGNAL(signalFeedsViewportUpdate()),
             parent, SLOT(slotFeedsViewportUpdate()));
     connect(parent, SIGNAL(signalSetFeedRead(int,int,int,QList<int>)),
-            updateObject_, SLOT(slotSetFeedRead(int,int,int,QList<int>)));
+            updateObject_, SLOT(slotSetFeedRead(int,int,int,QList<int>)),
+            Qt::DirectConnection);
     connect(parent, SIGNAL(signalMarkFeedRead(int,bool,bool)),
             updateObject_, SLOT(slotMarkFeedRead(int,bool,bool)));
     connect(parent, SIGNAL(signalRefreshInfoTray()),
@@ -149,6 +154,8 @@ UpdateFeeds::UpdateFeeds(QObject *parent, bool addFeed)
             updateObject_, SLOT(slotUpdateStatus(int,bool)));
     connect(parent, SIGNAL(signalMarkAllFeedsRead()),
             updateObject_, SLOT(slotMarkAllFeedsRead()));
+    connect(parent, SIGNAL(signalMarkReadCategory(int,int)),
+            updateObject_, SLOT(slotMarkReadCategory(int,int)));
     connect(parent, SIGNAL(signalRefreshNewsView(int)),
             updateObject_, SIGNAL(signalMarkAllFeedsRead(int)));
     connect(updateObject_, SIGNAL(signalMarkAllFeedsRead(int)),
@@ -159,7 +166,7 @@ UpdateFeeds::UpdateFeeds(QObject *parent, bool addFeed)
     connect(parent, SIGNAL(signalSetFeedsFilter(bool)),
             updateObject_, SIGNAL(signalSetFeedsFilter(bool)));
     connect(updateObject_, SIGNAL(signalSetFeedsFilter(bool)),
-            parent, SLOT(setFeedsFilter(bool)));
+            parent, SLOT(setFeedsFilter(bool)), Qt::QueuedConnection);
 
     connect(mainApp, SIGNAL(signalSqlQueryExec(QString)),
             updateObject_, SLOT(slotSqlQueryExec(QString)));
@@ -176,6 +183,11 @@ UpdateFeeds::UpdateFeeds(QObject *parent, bool addFeed)
     connect(updateObject_, SIGNAL(signalIconUpdate(int,QByteArray)),
             parent, SLOT(slotIconFeedUpdate(int,QByteArray)));
 
+    connect(parent, SIGNAL(signalQuitApp()),
+            updateObject_, SLOT(quitApp()));
+    connect(this, SIGNAL(signalSaveMemoryDatabase()),
+            updateObject_, SLOT(saveMemoryDatabase()));
+
     updateObject_->moveToThread(updateFeedThread_);
     faviconObject_->moveToThread(getFaviconThread_);
 
@@ -184,16 +196,6 @@ UpdateFeeds::UpdateFeeds(QObject *parent, bool addFeed)
     startSaveTimer();
   }
 
-#ifndef QT_NO_NETWORKPROXY
-  qRegisterMetaType<QNetworkProxy>("QNetworkProxy");
-#endif
-  connect(requestFeed_, SIGNAL(authenticationRequired(QNetworkReply*,QAuthenticator*)),
-          mainApp->mainWindow(), SLOT(slotAuthentication(QNetworkReply*,QAuthenticator*)),
-          Qt::BlockingQueuedConnection);
-  connect(requestFeed_, SIGNAL(proxyAuthenticationRequired(QNetworkProxy,QAuthenticator*)),
-          mainApp->mainWindow(), SLOT(slotProxyAuthentication(QNetworkProxy,QAuthenticator*)),
-          Qt::BlockingQueuedConnection);
-
   requestFeed_->moveToThread(getFeedThread_);
   parseObject_->moveToThread(updateFeedThread_);
 
@@ -203,6 +205,18 @@ UpdateFeeds::UpdateFeeds(QObject *parent, bool addFeed)
 
 UpdateFeeds::~UpdateFeeds()
 {
+  requestFeed_->deleteLater();
+  parseObject_->deleteLater();
+
+  if (!addFeed_) {
+    updateObject_->deleteLater();
+    faviconObject_->deleteLater();
+
+    getFaviconThread_->exit();
+    getFaviconThread_->wait();
+    delete getFaviconThread_;
+  }
+
   getFeedThread_->exit();
   getFeedThread_->wait();
   delete getFeedThread_;
@@ -210,26 +224,21 @@ UpdateFeeds::~UpdateFeeds()
   updateFeedThread_->exit();
   updateFeedThread_->wait();
   delete updateFeedThread_;
-
-  delete requestFeed_;
-  delete parseObject_;
-
-  if (!addFeed_) {
-    getFaviconThread_->exit();
-    getFaviconThread_->wait();
-    delete getFaviconThread_;
-
-    delete updateObject_;
-    delete faviconObject_;
-  }
 }
 
 void UpdateFeeds::disconnectObjects()
 {
-  updateObject_->disconnect(updateObject_);
-  requestFeed_->disconnect(requestFeed_);
-  parseObject_->disconnect(parseObject_);
-  faviconObject_->disconnect(faviconObject_);
+  if (!addFeed_) {
+    updateObject_->disconnect(updateObject_);
+    updateObject_->disconnect(parseObject_);
+    updateObject_->disconnect(requestFeed_);
+    updateObject_->disconnect(parent());
+    faviconObject_->disconnectObjects();
+  }
+
+  requestFeed_->disconnectObjects();
+  requestFeed_->disconnect(parent());
+  parseObject_->disconnectObjects();
 }
 
 void UpdateFeeds::startSaveTimer()
@@ -251,12 +260,7 @@ void UpdateFeeds::saveMemoryDatabase()
   if (!mainApp->storeDBMemory()) return;
   if (updateObject_->isSaveMemoryDatabase) return;
 
-  QTimer::singleShot(0, updateObject_, SLOT(saveMemoryDatabase()));
-}
-
-void UpdateFeeds::quitApp()
-{
-  QTimer::singleShot(0, updateObject_, SLOT(quitApp()));
+  emit signalSaveMemoryDatabase();
 }
 
 //------------------------------------------------------------------------------
@@ -278,10 +282,12 @@ UpdateObject::UpdateObject(QObject *parent)
   timerUpdateNews_ = new QTimer(this);
   timerUpdateNews_->setSingleShot(true);
   connect(timerUpdateNews_, SIGNAL(timeout()), this, SIGNAL(signalUpdateNews()));
+
 }
 
 UpdateObject::~UpdateObject()
 {
+
 }
 
 void UpdateObject::slotGetFeedTimer(int feedId)
@@ -361,9 +367,9 @@ void UpdateObject::slotImportFeeds(QByteArray xmlData)
   QString convertData;
   bool codecOk = false;
 
-  QRegExp rx("&(?!([a-z0-9#]+;))", Qt::CaseInsensitive, QRegExp::RegExp2);
+  QzRegExp rx("&(?!([a-z0-9#]+;))", Qt::CaseInsensitive);
   int pos = 0;
-  while ((pos = rx.indexIn(xmlData, pos)) != -1) {
+  while ((pos = rx.indexIn(QString::fromLatin1(xmlData), pos)) != -1) {
     xmlData.replace(pos, 1, "&amp;");
     pos += 1;
   }
@@ -739,7 +745,7 @@ void UpdateObject::slotRecountFeedCounts(int feedId, bool updateViewport)
   } else {
     bool changed = false;
     QList<int> idParList;
-    QList<int> idList = getIdFeedsInList(feedId);
+    QList<int> idList = getIdFeedsInList(db_, feedId);
     if (idList.count()) {
       foreach (int id, idList) {
         int parId = 0;
@@ -888,7 +894,7 @@ void UpdateObject::slotRecountFeedCounts(int feedId, bool updateViewport)
  *---------------------------------------------------------------------------*/
 QString UpdateObject::getIdFeedsString(int idFolder, int idException)
 {
-  QList<int> idList = getIdFeedsInList(idFolder);
+  QList<int> idList = getIdFeedsInList(db_, idFolder);
   if (idList.count()) {
     QString str;
     foreach (int id, idList) {
@@ -904,12 +910,12 @@ QString UpdateObject::getIdFeedsString(int idFolder, int idException)
 
 /** @brief Get feeds ids list of folder \a idFolder
  *---------------------------------------------------------------------------*/
-QList<int> UpdateObject::getIdFeedsInList(int idFolder)
+QList<int> UpdateObject::getIdFeedsInList(QSqlDatabase &db, int idFolder)
 {
   QList<int> idList;
   if (idFolder <= 0) return idList;
 
-  QSqlQuery q;
+  QSqlQuery q(db);
   QQueue<int> parentIds;
   parentIds.enqueue(idFolder);
   while (!parentIds.empty()) {
@@ -932,9 +938,11 @@ QList<int> UpdateObject::getIdFeedsInList(int idFolder)
  *---------------------------------------------------------------------------*/
 void UpdateObject::slotSetFeedRead(int readType, int feedId, int idException, QList<int> idNewsList)
 {
+  QSqlDatabase db = QSqlDatabase::database();
+  QSqlQuery q(db);
+
   if (readType != FeedReadSwitchingTab) {
-    db_.transaction();
-    QSqlQuery q(db_);
+    db.transaction();
     QString idFeedsStr = getIdFeedsString(feedId, idException);
     if (((readType == FeedReadSwitchingFeed) && mainWindow_->markReadSwitchingFeed_) ||
         ((readType == FeedReadClosingTab) && mainWindow_->markReadClosingTab_) ||
@@ -942,7 +950,7 @@ void UpdateObject::slotSetFeedRead(int readType, int feedId, int idException, QL
       if (idFeedsStr == "feedId=-1") {
         q.exec(QString("UPDATE news SET read=2 WHERE feedId='%1' AND read!=2").arg(feedId));
       } else {
-        q.exec(QString("UPDATE news SET read=2 WHERE (%1) AND read=1").arg(idFeedsStr));
+        q.exec(QString("UPDATE news SET read=2 WHERE (%1) AND read!=2").arg(idFeedsStr));
       }
     } else {
       if (idFeedsStr == "feedId=-1") {
@@ -958,14 +966,13 @@ void UpdateObject::slotSetFeedRead(int readType, int feedId, int idException, QL
     }
     if (mainWindow_->markNewsReadOn_ && mainWindow_->markPrevNewsRead_)
       q.exec(QString("UPDATE news SET read=2 WHERE id IN (SELECT currentNews FROM feeds WHERE id='%1')").arg(feedId));
-    db_.commit();
+    db.commit();
 
     slotRecountFeedCounts(feedId);
     slotRecountCategoryCounts();
 
-    if (readType != FeedReadPlaceToTray) {
+    if (readType != FeedReadPlaceToTray)
       slotRefreshInfoTray();
-    }
   } else {
     QString idStr;
     foreach (int newsId, idNewsList) {
@@ -973,11 +980,10 @@ void UpdateObject::slotSetFeedRead(int readType, int feedId, int idException, QL
       idStr.append(QString("id='%1'").arg(newsId));
     }
 
-    db_.transaction();
-    QSqlQuery q(db_);
+    db.transaction();
     q.exec(QString("UPDATE news SET read=2 WHERE (%1) AND read==1").arg(idStr));
     q.exec(QString("UPDATE news SET new=0 WHERE (%1) AND new==1").arg(idStr));
-    db_.commit();
+    db.commit();
 
     if (feedId > -1)
       slotRecountFeedCounts(feedId, false);
@@ -1078,6 +1084,41 @@ void UpdateObject::slotMarkAllFeedsRead()
   emit signalMarkAllFeedsRead();
 }
 
+void UpdateObject::slotMarkReadCategory(int type, int idLabel)
+{
+  QString qStr;
+  switch (type) {
+  case NewsTabWidget::TabTypeUnread:
+    qStr = "feedId > 0 AND deleted = 0 AND read < 2";
+    break;
+  case NewsTabWidget::TabTypeStar:
+    qStr = "feedId > 0 AND deleted = 0 AND starred = 1";
+    break;
+  case NewsTabWidget::TabTypeLabel:
+    if (idLabel != 0) {
+      qStr = QString("feedId > 0 AND deleted = 0 AND label LIKE '%,%1,%'").
+          arg(idLabel);
+    } else {
+      qStr = QString("feedId > 0 AND deleted = 0 AND label!='' AND label!=','");
+    }
+    break;
+  }
+
+  QSqlQuery q;
+  q.exec(QString("UPDATE news SET read=1 WHERE %1").arg(qStr));
+  q.exec(QString("UPDATE news SET new=0 WHERE %1").arg(qStr));
+
+  QList<int> idList;
+  q.exec("SELECT id FROM feeds WHERE unread!=0");
+  while (q.next()) {
+    idList.append(q.value(0).toInt());
+  }
+  emit signalMarkAllFeedsRead(0);
+  foreach (int id, idList) {
+    slotUpdateStatus(id, true);
+  }
+}
+
 /** @brief Save icon in DB and emit signal to update it
  *----------------------------------------------------------------------------*/
 void UpdateObject::slotIconSave(QString feedUrl, QByteArray faviconData)
@@ -1123,7 +1164,7 @@ void UpdateObject::slotMarkAllFeedsOld()
   slotRecountCategoryCounts();
 
   if ((mainWindow_->currentNewsTab != NULL) && (mainWindow_->currentNewsTab->type_ < NewsTabWidget::TabTypeWeb)) {
-    emit signalUpdateNews();
+    emit signalUpdateNews(NewsTabWidget::RefreshWithPos);
   }
 
   slotRefreshInfoTray();
@@ -1131,8 +1172,6 @@ void UpdateObject::slotMarkAllFeedsOld()
 
 void UpdateObject::slotRefreshInfoTray()
 {
-  if (!mainWindow_->showTrayIcon_) return;
-
   // Calculate new and unread news number
   int newCount = 0;
   int unreadCount = 0;
@@ -1149,17 +1188,28 @@ void UpdateObject::slotRefreshInfoTray()
 void UpdateObject::saveMemoryDatabase()
 {
   isSaveMemoryDatabase = true;
-  Database::sqliteDBMemFile();
+  Database::sqliteDBMemFile(db_);
   isSaveMemoryDatabase = false;
 }
 
 /** @brief Delete news from the feed by criteria
  *---------------------------------------------------------------------------*/
-void UpdateObject::cleanUpShutdown()
+void UpdateObject::startCleanUp(bool isShutdown, QStringList feedsIdList, QList<int> foldersIdList)
 {
+  bool cleanupOn = true;
+  bool optimizeDB = false;
+  bool fullCleanUp = false;
+  int countDeleted = 0;
+
   Settings settings;
-  settings.beginGroup("Settings");
-  bool cleanupOnShutdown = settings.value("cleanupOnShutdown", true).toBool();
+  if (isShutdown) {
+    settings.beginGroup("Settings");
+    cleanupOn = settings.value("cleanupOnShutdown", true).toBool();
+    optimizeDB = settings.value("optimizeDB", false).toBool();
+  } else {
+    settings.beginGroup("CleanUpWizard");
+    fullCleanUp = settings.value("fullCleanUp", false).toBool();
+  }
   int maxDayCleanUp = settings.value("maxDayClearUp", 30).toInt();
   int maxNewsCleanUp = settings.value("maxNewsClearUp", 200).toInt();
   bool dayCleanUpOn = settings.value("dayClearUpOn", true).toBool();
@@ -1169,35 +1219,27 @@ void UpdateObject::cleanUpShutdown()
   bool neverStarCleanUp = settings.value("neverStarClearUp", true).toBool();
   bool neverLabelCleanUp = settings.value("neverLabelClearUp", true).toBool();
   bool cleanUpDeleted = settings.value("cleanUpDeleted", false).toBool();
-  bool optimizeDB = settings.value("optimizeDB", false).toBool();
   settings.endGroup();
 
-  QSqlQuery q;
-  QString qStr;
-
-  if (!mainApp->storeDBMemory())
-    db_ = QSqlDatabase::database();
   db_.transaction();
 
-  q.exec("UPDATE news SET new=0 WHERE new==1");
-  q.exec("UPDATE news SET read=2 WHERE read==1");
-  q.exec("UPDATE feeds SET newCount=0 WHERE newCount!=0");
+  QSqlQuery q(db_);
+  QString qStr;
 
-  if (cleanupOnShutdown) {
-    QList<int> feedsIdList;
-    QList<int> foldersIdList;
-    q.exec("SELECT id, xmlUrl FROM feeds");
-    while (q.next()) {
-      if (q.value(1).toString().isEmpty()) {
-        foldersIdList << q.value(0).toInt();
-      }
-      else {
-        feedsIdList << q.value(0).toInt();
-      }
+  if (isShutdown) {
+    q.exec("UPDATE news SET new=0 WHERE new==1");
+    q.exec("UPDATE news SET read=2 WHERE read==1");
+    q.exec("UPDATE feeds SET newCount=0 WHERE newCount!=0");
+  }
+
+  if (cleanupOn) {
+    if (!isShutdown) {
+      q.exec("SELECT count(id) FROM news WHERE deleted < 2");
+      if (q.first()) countDeleted = q.value(0).toInt();
     }
 
     // Run Cleanup for all feeds, except categories
-    foreach (int feedId, feedsIdList) {
+    foreach (QString feedId, feedsIdList) {
       int countDelNews = 0;
       int countAllNews = 0;
 
@@ -1205,6 +1247,9 @@ void UpdateObject::cleanUpShutdown()
       q.exec(qStr);
       if (q.next()) countAllNews = q.value(0).toInt();
 
+      if (fullCleanUp)
+        q.exec(QString("DELETE FROM news WHERE feedId=='%1' AND deleted >= 2").arg(feedId));
+
       QString qStr1 = QString("UPDATE news SET description='', content='', received='', "
                               "author_name='', author_uri='', author_email='', "
                               "category='', new='', read='', starred='', label='', "
@@ -1221,28 +1266,35 @@ void UpdateObject::cleanUpShutdown()
         int newsId = q.value(0).toInt();
 
         if (newsCleanUpOn && (countDelNews < (countAllNews - maxNewsCleanUp))) {
-          qStr = QString("%1 WHERE id=='%2'").arg(qStr1).arg(newsId);
-          QSqlQuery qt;
+          if (fullCleanUp)
+            qStr = QString("DELETE FROM news WHERE id='%1'").arg(newsId);
+          else
+            qStr = QString("%1 WHERE id=='%2'").arg(qStr1).arg(newsId);
+          QSqlQuery qt(db_);
           qt.exec(qStr);
           countDelNews++;
           continue;
         }
 
-        QDateTime dateTime = QDateTime::fromString(
-              q.value(1).toString(),
-              Qt::ISODate);
+        QDateTime dateTime = QDateTime::fromString(q.value(1).toString(), Qt::ISODate);
         if (dayCleanUpOn &&
             (dateTime.daysTo(QDateTime::currentDateTime()) > maxDayCleanUp)) {
-          qStr = QString("%1 WHERE id=='%2'").arg(qStr1).arg(newsId);
-          QSqlQuery qt;
+          if (fullCleanUp)
+            qStr = QString("DELETE FROM news WHERE id='%1'").arg(newsId);
+          else
+            qStr = QString("%1 WHERE id=='%2'").arg(qStr1).arg(newsId);
+          QSqlQuery qt(db_);
           qt.exec(qStr);
           countDelNews++;
           continue;
         }
 
         if (readCleanUp) {
-          qStr = QString("%1 WHERE read!=0 AND id=='%2'").arg(qStr1).arg(newsId);
-          QSqlQuery qt;
+          if (fullCleanUp)
+            qStr = QString("DELETE FROM news WHERE id='%1'").arg(newsId);
+          else
+            qStr = QString("%1 WHERE read!=0 AND id=='%2'").arg(qStr1).arg(newsId);
+          QSqlQuery qt(db_);
           qt.exec(qStr);
           countDelNews++;
         }
@@ -1260,8 +1312,18 @@ void UpdateObject::cleanUpShutdown()
       q.exec(qStr);
       if (q.next()) unreadCount = q.value(0).toInt();
 
-      qStr = QString("UPDATE feeds SET unread='%1', undeleteCount='%2' WHERE id=='%3'").
-          arg(unreadCount).arg(undeleteCount).arg(feedId);
+      int newCount = 0;
+      if (!isShutdown) {
+        qStr = QString("SELECT count(new) FROM news WHERE feedId=='%1' AND new==1 AND deleted==0").
+            arg(feedId);
+        q.exec(qStr);
+        if (q.next()) newCount = q.value(0).toInt();
+        qStr = QString("UPDATE feeds SET unread='%1', newCount='%2', undeleteCount='%3' WHERE id=='%4'").
+            arg(unreadCount).arg(newCount).arg(undeleteCount).arg(feedId);
+      } else {
+        qStr = QString("UPDATE feeds SET unread='%1', undeleteCount='%2' WHERE id=='%3'").
+            arg(unreadCount).arg(undeleteCount).arg(feedId);
+      }
       q.exec(qStr);
     }
 
@@ -1274,19 +1336,21 @@ void UpdateObject::cleanUpShutdown()
       while (0 < folderId) {
         int unreadCount = -1;
         int undeleteCount = -1;
+        int newCount = -1;
 
         // Calculate sum of all feeds with same parent
-        qStr = QString("SELECT sum(unread), sum(undeleteCount) FROM feeds "
-                       "WHERE parentId=='%1'").arg(folderId);
+        qStr = QString("SELECT sum(unread), sum(undeleteCount), sum(newCount) "
+                       "FROM feeds WHERE parentId=='%1'").arg(folderId);
         q.exec(qStr);
         if (q.next()) {
           unreadCount   = q.value(0).toInt();
           undeleteCount = q.value(1).toInt();
+          newCount = q.value(2).toInt();
         }
 
         if (unreadCount != -1) {
-          qStr = QString("UPDATE feeds SET unread='%1', undeleteCount='%2' WHERE id=='%3'").
-              arg(unreadCount).arg(undeleteCount).arg(folderId);
+          qStr = QString("UPDATE feeds SET unread='%1', undeleteCount='%2', newCount='%3' WHERE id=='%4'").
+              arg(unreadCount).arg(undeleteCount).arg(newCount).arg(folderId);
           q.exec(qStr);
         }
 
@@ -1304,32 +1368,51 @@ void UpdateObject::cleanUpShutdown()
              "category='', new='', read='', starred='', label='', "
              "deleteDate='', feedParentId='', deleted=2 WHERE deleted==1");
     }
+    if (!isShutdown) {
+      q.exec("SELECT count(id) FROM news WHERE deleted < 2");
+      if (q.first()) countDeleted = countDeleted - q.value(0).toInt();
+    }
   }
 
   q.finish();
   db_.commit();
 
-  if (cleanupOnShutdown && optimizeDB && !mainApp->storeDBMemory()) {
-    db_.exec("VACUUM");
+  if (!mainApp->storeDBMemory()) {
+    if ((cleanupOn && optimizeDB) || !isShutdown)
+      db_.exec("VACUUM");
+  } else {
+    saveMemoryDatabase();
+    if ((cleanupOn && optimizeDB) || !isShutdown)
+      Database::setVacuum();
   }
+
+  emit signalFinishCleanUp(countDeleted);
+}
+
+/** @brief Delete news from the feed by criteria
+ *---------------------------------------------------------------------------*/
+void UpdateObject::cleanUpShutdown()
+{
+  QSqlQuery q(db_);
+  QStringList feedsIdList;
+  QList<int> foldersIdList;
+  q.exec("SELECT id, xmlUrl FROM feeds");
+  while (q.next()) {
+    if (q.value(1).toString().isEmpty()) {
+      foldersIdList << q.value(0).toInt();
+    }
+    else {
+      feedsIdList << q.value(0).toString();
+    }
+  }
+  q.finish();
+
+  startCleanUp(true, feedsIdList, foldersIdList);
 }
 
 void UpdateObject::quitApp()
 {
   cleanUpShutdown();
 
-  if (mainApp->storeDBMemory()) {
-    saveMemoryDatabase();
-
-    Settings settings;
-    settings.beginGroup("Settings");
-    bool cleanupOnShutdown = settings.value("cleanupOnShutdown", true).toBool();
-    bool optimizeDB = settings.value("optimizeDB", false).toBool();
-    settings.endGroup();
-    if (cleanupOnShutdown && optimizeDB) {
-      Database::setVacuum();
-    }
-  }
-
   QTimer::singleShot(0, mainApp, SLOT(quitApplication()));
 }
